SVGL class

Constructors

SVGL()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

ai → AiLogos
A collection of AI-related brand icons.
no setter
authentication → AuthenticationLogos
A collection of Authentication-related brand icons.
no setter
browser → BrowserLogos
A collection of Browser-related brand icons.
no setter
cms → CmsLogos
A collection of CMS-related brand icons.
no setter
community → CommunityLogos
A collection of Community-related brand icons.
no setter
compiler → CompilerLogos
A collection of Compiler-related brand icons.
no setter
config → ConfigLogos
A collection of Config-related brand icons.
no setter
crypto → CryptoLogos
A collection of Crypto-related brand icons.
no setter
cybersecurity → CybersecurityLogos
A collection of Cybersecurity-related brand icons.
no setter
database → DatabaseLogos
A collection of Database-related brand icons.
no setter
design → DesignLogos
A collection of Design-related brand icons.
no setter
devtool → DevtoolLogos
A collection of DevTool-related brand icons.
no setter
education → EducationLogos
A collection of Education-related brand icons.
no setter
entertainment → EntertainmentLogos
A collection of Entertainment-related brand icons.
no setter
framework → FrameworkLogos
A collection of Framework-related brand icons.
no setter
google → GoogleLogos
A collection of Google-related brand icons.
no setter
hardware → HardwareLogos
A collection of Hardware-related brand icons.
no setter
hosting → HostingLogos
A collection of Hosting-related brand icons.
no setter
iot → IotLogos
A collection of IoT-related brand icons.
no setter
language → LanguageLogos
A collection of Language-related brand icons.
no setter
library → LibraryLogos
A collection of Library-related brand icons.
no setter
marketplace → MarketplaceLogos
A collection of Marketplace-related brand icons.
no setter
music → MusicLogos
A collection of Music-related brand icons.
no setter
payment → PaymentLogos
A collection of Payment-related brand icons.
no setter
secrets → SecretsLogos
A collection of Secrets-related brand icons.
no setter
social → SocialLogos
A collection of Social-related brand icons.
no setter
software → SoftwareLogos
A collection of Software-related brand icons.
no setter
vercel → VercelLogos
A collection of Vercel-related brand icons.
no setter